ninka
=====

認可 ninka - permission, license

Python package to help working with IndieAuth.

Roadmap
=======
Working
* IndieAuth tools
* MicroPub support

See the examples/ directory for sample command line tools.

Contributors
============
* bear (Mike Taylor)

IndieAuth
=========
discoverAuthEndpoints()
-----------------------
Find the authorization or redirect_uri endpoints for the given authDomain.

validateAuthCode()
------------------
Call authorization endpoint to validate given auth code.

Requires
========
Python v2.7+ but see requirements.txt for a full list
